#
# spec file for package mygnuhealth
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2020-2023 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname MyGNUHealth
%define majorver 2

#boo#1181905
%global __requires_exclude qmlimport\\((BloodPressure|FedLogin|GHBio|GHBol|GHPsycho|Glucose|LocalAccountManager|MoodEnergy|NetworkSettings|Osat|ProfileSettings|Weight|PoL|GHLifestyle|GHPhysicalActivity|GHNutrition|GHSleep|GHAbout)

%if %{?suse_version} > 1500
# only the primary one for TW
%define pythons python3
%define mypython python3
%define mypython_sitelib %{python3_sitelib}
%else
# needs Python 3.9+
%{?sle15_python_module_pythons}
# use the one define in sle15_python_module_pythons
%define mypython %pythons
%define mypython_sitelib %{expand:%%%{mypython}_sitelib}
%endif

Name:           mygnuhealth
Version:        %{majorver}.0.0
Release:        1.1
Summary:        The personal health record for the GNU Health system
License:        GPL-3.0-or-later
Group:          Productivity/Office/Management
URL:            http://health.gnu.org/
Source:         https://ftp.gnu.org/gnu/health/mygnuhealth/%{name}-%{version}.tar.gz
Source1:        https://ftp.gnu.org/gnu/health/mygnuhealth/%{name}-%{version}.tar.gz.sig
Source2:        https://savannah.gnu.org/project/memberlist-gpgkeys.php?group=health&download=1#/%{name}.keyring
Patch0:         remove-obsolete-deps.patch
# SECTION build
BuildRequires:  fdupes
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module setuptools >= 61}
BuildRequires:  %{python_module pip}
BuildRequires:  update-desktop-files
BuildRequires:  python-rpm-macros
# /SECTION
# SECTION test requirements
# there are no tests, but at least check that all the runtime requirements are available on build time
BuildRequires:  %{python_module bcrypt}
BuildRequires:  %{python_module Kivy}
BuildRequires:  %{python_module pygal}
BuildRequires:  %{python_module tinydb}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module CairoSVG}
Requires:       %{mypython}-bcrypt
Requires:       %{mypython}-Kivy
Requires:       %{mypython}-pygal
Requires:       %{mypython}-tinydb
Requires:       %{mypython}-requests
Requires:       %{mypython}-CairoSVG
# /SECTION
BuildArch:      noarch
# singlespec rewriter for exactly one python (see above)


%description
The Personal Health Information Management System for Desktop and Mobile Devices
for the GNU Health ecosystem

%package -n %{name}-doc
Summary:        Documentation files for MyGNUHealth
Group:          Productivity/Office/Management

%description -n %{name}-doc
This package includes the documentation for MyGNUHealth Personal Health
Information Management System for Desktop and Mobile Devices

%prep
%autosetup -p1 -n %{name}

%build
%pyproject_wheel

%install
%pyproject_install

# remove shebang
%python_expand sed -i '1{/env python/d}' %{buildroot}%{python_sitelib}/mygnuhealth/*.py

# menu-entry
desktop-file-install --dir %{buildroot}%{_datadir}/applications org.gnuhealth.mygnuhealth.desktop
%suse_update_desktop_file org.gnuhealth.mygnuhealth

%python_expand %fdupes %{buildroot}%{python_sitelib}

# install and deduplicate doc
mkdir -p %{buildroot}%{_docdir}/%{name}-doc/
cp -r doc/* %{buildroot}%{_docdir}/%{name}-doc/
%fdupes %{buildroot}%{_docdir}

%post
#clean qml cache to avoid issues
rm -rf /home/*/.cache/mygnuhealth

%postun
#clean qml cache - housekeeping
rm -rf /home/*/.cache/mygnuhealth

%files
%attr(755,root,root) %{_bindir}/%{name}
%{_datadir}/applications/org.gnuhealth.mygnuhealth.desktop
%license COPYRIGHT LICENSE
%{mypython_sitelib}/mygnuhealth
%{mypython_sitelib}/mygnuhealth-%{version}.dist-info


%files -n %{name}-doc
%doc README.rst
%{_docdir}/*

%changelog
* Fri Sep 29 2023 Ben Greiner <code@bnavigator.de>
- Fix single singlespec: Can't use python_subpackages rewriter
* Fri Sep 29 2023 Ben Greiner <code@bnavigator.de>
- Remove dependencies which are not used at runtime anywhere
  * only CairoSVG is reqired for PNG charts since at least
    pygal 1.7:
    https://github.com/Kozea/pygal/blob/1.6.2/setup.py#L70
  * remove-obsolete-deps.patch
* Fri Sep 29 2023 Ben Greiner <code@bnavigator.de>
- Back to singlespec for a single flavor in order to
  use sle15_python_module_pythons
* Fri Sep 29 2023 Ben Greiner <code@bnavigator.de>
- Fix BuildRequirements
- Fix doc package duplicate file warning
- Remove stray singlespec
* Wed Sep 27 2023 Axel Braun <axel.braun@gmx.de>
- Version 2.0.0
  * complete rewrite based on Kivy (instead Kirigami)
  * For Details see CHANGELOG
  * doc_path.diff removed
  * shebang.diff removed
* Fri Mar 11 2022 Axel Braun <axel.braun@gmx.de>
- License string corrected
* Tue Oct 19 2021 Axel Braun <axel.braun@gmx.de>
- version 1.0.5
  * switched source download to gnu.org, added signature
  * added documentation in DE, ES, FR
  * Minor adjustmends
* Mon Aug 23 2021 Axel Braun <axel.braun@gmx.de>
- version 1.0.4
  * fixes plotting issues when matplotlib uses unsorted records or dup
  batch inputs.
* Sun Jul 25 2021 Axel Braun <axel.braun@gmx.de>
- version 1.0.3
  * update of Uniprot-database
  * some minor changes / updates in the documentation and credits
* Thu Jul 15 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.0.2
  * MyGNUHealth does not display global menu on MATE
  * Update link from GNU Savannah
* Thu Jul  8 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.0.1
  * Fix the download path within GNU.org. Now it points to
  https://ftp.gnu.org/gnu/health/mygnuhealth/
  * Include Changelog file
  * Include local / offline documentation (resides on
  /usr/share/doc/packages/mygnuhealth)
  * doc_path.diff added
  * Clean up __pycache__ from tarball
* Thu Jun 24 2021 Axel Braun <axel.braun@gmx.de>
- Version 1.0.0
* Sat Oct 31 2020 Axel Braun <axel.braun@gmx.de>
- Version 0.7a6
  initial OBS build
